Examples
========

These examples show how to use Coiled and Dask for a variety of use cases.

.. toctree::
   :maxdepth: 1
   :hidden:

   examples/dask-sql.ipynb
   examples/prefect
   examples/snowflake
   examples/mongodb.ipynb
   examples/streamlit
   examples/xgboost.ipynb
   examples/jupyterlab.ipynb

.. panels::
   :body: text-center
   :header: text-center h5 bg-white
   :footer: border-2 bg-white

   |
   | **Distributed SQL queries with Dask-SQL**
   |

   .. link-button:: examples/dask-sql
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Workflow automation with Prefect**
   |

   .. link-button:: examples/prefect
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link
    
   ---

   |
   | **Faster data transfer with Snowflake**
   |

   .. link-button:: examples/snowflake
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Parallel read and write with MongoDB**
   |

   .. link-button:: examples/mongodb
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Deploy web applications with Streamlit**
   |

   .. link-button:: examples/streamlit
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Scaling XGBoost with Dask and Coiled**
   |

   .. link-button:: examples/xgboost
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link
    

   ---

   |
   | **Using Coiled with JupyterLab**
   |

   .. link-button:: examples/jupyterlab
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **ETL automation with GitHub Actions**
   |

   .. link-button:: https://coiled.io/blog/github-actions-s3-deploy/
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Hyperparameter tuning with Optuna**
   |

   .. link-button:: https://coiled.io/blog/scalable-hyperparameter-optimization-optuna-dask/
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Faster model training with scikit-learn**
   |

   .. link-button:: https://coiled.io/blog/sklearn-joblib-dask/
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   |
   | **Scalability for your Dash app in the cloud**
   |

   .. link-button:: https://dash.plotly.com/dask-dash-coiled
      :text: Learn more
      :classes: btn-full btn-block stretched-link